@@ -6,7 +6,6 @@ print "Loaded module\nFinding IP address\n";
 my $ifc = join "", `ifconfig`;
 $ifc =~ m/addr:(\d+\.\d+\.\d+\.\d+)/s;
 my $addr = $1;
-claim_hostname("wiggles", "10.11.11.11");
-#service("myhost", $addr, 444, "perl", "tcp");
+service("myhost", $addr, 444, "perl", "tcp");
 print "Loaded service\n";
 while (1) {process_network_events}
